function [thta,q] = theta_q(pres,tmpc,relh)
%
%  function [thta,q] = theta_q(pres,tmpc,relh)
% 
%  written by:  Mary Jordan, NPS Meteorology Dept, 10/9/96
%
%  Purpose:	Calculates Potential Temperature (thta) and
%		Specific Humidity (q)
%
%  Reference:  Atmospheric Science by Wallace & Hobbs, 1977, Academic Press
%
%  Input:	pres = Pressure (mb)
%		tmpc = Air Temperature (C)
%		relh = Relative Humidity (%)
%
%  Output:	thta = Potential Temperature (K)
%		   q = Specific Humidity (g/kg)
%
% ------------------------------------------------------------

%
% define local constants for thermodynamic equations:
	p0=1000.;R=287.;cp=1004.;L=2.5e6; 
%
tmpk = tmpc+273.155;			% convert to tmpc to Kelvin

%   saturation vapor pressure, e_s
e_s = 6.1078*exp((17.26939.*tmpc)./(tmpc+237.3));

%   vapor pressure, ee   
ee = (relh ./ 100.) .* e_s; 

w = 0.622 * (ee ./ (pres - ee));  	% mixing ratio (kg/kg)
q_kg = w ./ (1.0 + w);         	% specific humidity (kg/kg)

q=q_kg*1000;				% specific humidity (g/kg)

%   Potential Temperature (K)
thta = tmpk .* ((p0 ./ pres).^(R/cp)); 

%------------------------------------------------------------
