    function [eh2o,q] = water(pres,tmpc,relh)
%
% 
%  Basicly from thetaq by  Mary Jordan, NPS Meteorology Dept, 10/9/96
%
%  Input: pres = Pressure (mb)
%         tmpc = Air Temperature (C)
%         relh = Relative Humidity (%)
%
%  Output:   eh2o  =  partial pressure H2o
%            q     = Specific Humidity (g/kg)
%
% ------------------------------------------------------------

%
% define local constants for thermodynamic equations:
%
     p0  =  1000.;
     R   =   287.;
     cp  =  1004.;
     L   =  2.5e6; 
%
     tmpk = tmpc+273.155;

%   saturation vapor pressure, e_s
%
     e_s = 6.1078*exp((17.26939.*tmpc)./(tmpc+237.3));

%   vapor pressure, ee   
%    
     ee = (relh ./ 100.) .* e_s; 
%
%         mixing ration (kg/kg), specific humidity (kg/kg)
%
     w    = 0.622 * (ee ./ (pres - ee));
     q_kg = w ./ (1.0 + w);
%
%         standard q, as g/kg
%
     q      =  q_kg*1000;
     eh2o   =  ee;
%
%------------------------------------------------------------
